@@ -39,7 +39,9 @@
 
 #define HOME_DIR g_get_home_dir()
 
-#define IP_COMMAND "/sbin/ifconfig | grep \"inet addr\" | awk -F: '{print $2}' | awk '{print $1}'"
+#define IP_COMMAND "/sbin/ifconfig | grep \"inet addr\" | awk -F: '{print $2}' | awk '{print $1}' | grep -v \"127.0.0.1\""
+//#define INTERFACE_COMMAND "/sbin/ifconfig -a| tr -s ' ' | sed 's/ /,/' | tr '\n' \| | sed 's/||/\n/' | grep \"inet addr\" | grep -v \"127.0.0.1\""
+#define INTERFACE_COMMAND "/sbin/ifconfig | tr '\\n' \\~ | sed 's/\\~\\~/\\n/g\' | grep \"inet addr\" | grep -v \"lo\" | awk '{print $1}'"
 
 #define _(String) dgettext("hildon-libs", String)
 
@@ -50,12 +52,15 @@
 struct _PersonalIpAddressPrivate
 {
     GtkWidget *homeWidget;
+	GtkWidget *event;
     GtkWidget *contents;
 	
 	GtkWidget *ipLabel;
 	GtkWidget *ipContent;
+	GtkWidget *interfaceContent;
 	
 	gint refresh;
+	gboolean isPressed;
 	
 	ConIcConnection *connection;
 	
@@ -136,10 +141,35 @@ void personal_ip_address_write_settings (PersonalIpAddress *self)
 	g_free (filename);
 }*/
 
+void personal_ip_address_button_press (GtkWidget *widget, GdkEventButton *event, PersonalIpAddress *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->isPressed = TRUE;
+	gtk_widget_queue_draw (GTK_WIDGET (self));
+}
+
+void personal_ip_address_button_release (GtkWidget *widget, GdkEventButton *event, PersonalIpAddress *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->isPressed = FALSE;
+	
+	con_ic_connection_connect (self->priv->connection, CON_IC_CONNECT_FLAG_NONE);
+	
+	gtk_widget_queue_draw (GTK_WIDGET (self));
+}
+
+void personal_ip_address_leave_event (GtkWidget *widget, GdkEventCrossing *event, PersonalIpAddress *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->isPressed = FALSE;
+	gtk_widget_queue_draw (GTK_WIDGET (self));
+}
+
 void personal_ip_address_content_create (PersonalIpAddress *self)
 {
 	//g_warning ("personal_ip_address_content_create");
-	self->priv->contents = gtk_vbox_new (FALSE, 0);
+	self->priv->contents = gtk_event_box_new ();
+	gtk_event_box_set_visible_window (GTK_EVENT_BOX (self->priv->contents), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 
@@ -172,46 +202,73 @@ void personal_ip_address_content_create (PersonalIpAddress *self)
 	gtk_box_pack_start (GTK_BOX (self->priv->contents), ipBox, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);*/
 	
-	GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
+	//GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
+	self->priv->ipLabel = gtk_label_new ("IP");
 	GtkWidget *box = gtk_hbox_new (FALSE, 0);
+	self->priv->interfaceContent = gtk_label_new ("");
 	self->priv->ipContent = gtk_label_new ("(no IP found)");
-	gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (box), self->priv->ipLabel, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (box), self->priv->interfaceContent, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (box), self->priv->ipContent, TRUE, TRUE, 0);
-	//hildon_helper_set_logical_font (self->priv->ipContent, "SmallSystemFont");
 	hildon_helper_set_logical_color (self->priv->ipContent, GTK_RC_FG, GTK_STATE_NORMAL, "ActiveTextColor");
-	gtk_misc_set_alignment (GTK_MISC (self->priv->ipContent), 1, 0.8);
+	hildon_helper_set_logical_color (self->priv->interfaceContent, GTK_RC_FG, GTK_STATE_NORMAL, "ActiveTextColor");
+	gtk_misc_set_alignment (GTK_MISC (self->priv->ipLabel), 0, 0);
+	gtk_misc_set_alignment (GTK_MISC (self->priv->ipContent), 1, 1);
 	gtk_misc_set_padding (GTK_MISC (self->priv->ipContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
+	gtk_misc_set_padding (GTK_MISC (self->priv->interfaceContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
+	gtk_misc_set_padding (GTK_MISC (self->priv->ipLabel), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
 
-	gtk_box_pack_start (GTK_BOX (self->priv->contents), box, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (self->priv->contents), box);
 	gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), self->priv->contents, FALSE, FALSE, 0);
 	
+	g_signal_connect (self->priv->contents, "button-release-event", G_CALLBACK (personal_ip_address_button_release), self);
+	g_signal_connect (self->priv->contents, "button-press-event", G_CALLBACK (personal_ip_address_button_press), self);
+	g_signal_connect (self->priv->contents, "leave-notify-event", G_CALLBACK (personal_ip_address_leave_event), self);
+	
     gtk_widget_show_all (self->priv->homeWidget);
 }
 
-gboolean personal_ip_address_update_content (ConIcConnection *connection, ConIcConnectionEvent *event, PersonalIpAddress *self)
+gboolean personal_ip_address_update_content (PersonalIpAddress *self)
 {
 	//g_warning ("personal_ip_address_update_content");
 	FILE *fp;
-	gchar line[130];
+	gchar line[256];
 	gboolean found = FALSE;
 
-	fp = popen (IP_COMMAND, "r");
+	fp = popen (INTERFACE_COMMAND, "r");
+	//g_warning ("/sbin/ifconfig | tr '\\n' \\~ | sed 's/\\~\\~/\\n/g\' | grep \"inet addr\" | grep -v \"lo\" | awk '{FS=\",\"} {print $1}'");
 
-	while (fgets (line, sizeof line, fp))
-	{
+	while (fgets (line, sizeof line, fp)) {
 		gchar *gline = g_strdup_printf ("%s", line);
-		if (g_strcasecmp (g_strstrip (gline), "127.0.0.1") != 0) {
-			gtk_label_set_text (GTK_LABEL (self->priv->ipContent), gline);
-			found = TRUE;
-		}
+		gtk_label_set_text (GTK_LABEL (self->priv->interfaceContent), g_strstrip (gline));
+		found = TRUE;
 		g_free (gline);
 	}
 	pclose (fp);
 	
-	if (!found) {
-		gtk_label_set_text (GTK_LABEL (self->priv->ipContent), "(no IP found)");
+	if (found) {
+		found = FALSE;
+		fp = popen (IP_COMMAND, "r");
+		
+		while (fgets (line, sizeof line, fp)) {
+			gchar *gline = g_strdup_printf ("%s", line);
+			gtk_label_set_text (GTK_LABEL (self->priv->ipContent), g_strstrip (gline));
+			found = TRUE;
+			g_free (gline);
+		}
+		pclose (fp);
 	}
 	
+	if (!found) {
+		gtk_label_set_text (GTK_LABEL (self->priv->interfaceContent), "");
+		gtk_label_set_text (GTK_LABEL (self->priv->ipContent), "(no IP found)");
+	}
+}
+
+gboolean personal_ip_address_connection_changed (ConIcConnection *connection, ConIcConnectionEvent *event, PersonalIpAddress *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	personal_ip_address_update_content (self);
 	return TRUE;
 }
 
@@ -339,17 +396,20 @@ static gboolean personal_ip_address_expose_event (GtkWidget *widget, GdkEventExp
 	cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
 
 	GdkColor color;
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "ContentFrameColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
+	if (!self->priv->isPressed) {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
+	} else {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+	}
 	
 	gint width, height, x, y;
 	gint radius = 5;
-	gint iconOffset = 16;
-	gint iconSize = 56;
 	width = widget->allocation.width;
-	height = iconSize - iconOffset;
+	height = widget->allocation.height;
 	x = widget->allocation.x;
-	y = widget->allocation.y + iconOffset;
+	y = widget->allocation.y;
 
 	cairo_move_to(cr, x + radius, y);
 	cairo_line_to(cr, x + width - radius, y);
@@ -402,15 +462,16 @@ static void personal_ip_address_init (PersonalIpAddress *self)
 	//g_warning ("personal_ip_address_init");
 	self->priv = PERSONAL_IP_ADDRESS_GET_PRIVATE (self);
 	self->priv->eventID = 0;
+	self->priv->isPressed = FALSE;
 	
 	self->priv->connection = con_ic_connection_new ();
-	g_signal_connect (self->priv->connection, "connection-event", G_CALLBACK (personal_ip_address_update_content), self);
+	g_signal_connect (self->priv->connection, "connection-event", G_CALLBACK (personal_ip_address_connection_changed), self);
 	g_object_set (self->priv->connection, "automatic-connection-events", TRUE);
 	
 	//hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	//g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_ip_address_settings), self);
 
-	gtk_window_set_default_size (GTK_WINDOW (self), 315, 56);
+	gtk_window_set_default_size (GTK_WINDOW (self), 315, 40);
 	
 	self->priv->homeWidget = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self), self->priv->homeWidget);
@@ -418,14 +479,15 @@ static void personal_ip_address_init (PersonalIpAddress *self)
 
 	GdkGeometry hints;
 	hints.min_width = 315;
-	hints.min_height = 56;
+	hints.min_height = 40;
 	hints.max_width = 315;
-	hints.max_height = 56;
+	hints.max_height = 40;
 	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
 	
 	//personal_ip_address_read_settings (self);
 	
 	personal_ip_address_content_create (self);
+	personal_ip_address_update_content (self);
 	
 	g_signal_connect (self, "notify::is-on-current-desktop", G_CALLBACK (personal_ip_address_check_desktop), self);
 }
